Thanks
------

Bidict has benefited from the assistance of many people and projects.


People
======

.. Remember to update "__credits__" in ../bidict/metadata.py when this is updated

- Gregory Ewing for the name.

- Terry Reedy for suggesting the slice syntax
  (it was fun while it lasted).

- Raymond Hettinger for suggesting namedbidict
  and pointing out various caveats.

- Francis Carr for the idea of storing the inverse bidict.

- Adopt Pytest Month 2015 for choosing bidict,
  Tom Viner for being bidict's Adopt Pytest helper for the month,
  and Brianna Laugher for coordinating.

- Daniel Pope for suggestions, code reviews, and design discussion.

- David Turner for code reviews and design discussion.

- Michael Arntzenius for design discussion.

- Jozef Knaperek for the bugfix.

- Igor Nehoroshev for contributing the py.typed marker.

- Bernát Gábor for pyproject.toml support.

- Muhammad Faisal for the
  `CC BY 3.0 <https://creativecommons.org/licenses/by/3.0/us/>`__
  `icon <https://thenounproject.com/term/book/1330481/>`__
  that bidict's logo was derived from.

- Richard Sanger, Zeyi Wang, and Amol Sahsrabudhe for reporting bugs.


Projects
========

- `Tidelift <https://tidelift.com/>`__
- `Pytest <https://docs.pytest.org/en/latest/>`__
- `Coverage <https://coverage.readthedocs.io/en/latest/>`__
- `hypothesis <https://hypothesis.readthedocs.io/en/latest/>`__
- `pytest-benchmark <https://github.com/ionelmc/pytest-benchmark>`__
- `Sphinx <http://www.sphinx-doc.org/en/stable/>`__
- `Readthedocs <https://readthedocs.org/>`__
- `Codecov <https://codecov.io/>`__
- `Pylint <https://www.pylint.org/>`__
- `Flake8 <http://flake8.pycqa.org/>`__
- `setuptools_scm <https://github.com/pypa/setuptools_scm>`__
